#!/usr/bin/wish -f

# Dialog for setting up the fvwm2-ade button bar's application-launching
# buttons.

# Greg Fall
# March 1998

# Reading required command-line arguments.

set base_dir [lindex $argv 0]   ;# fvwm2-ade installation directory.
set module_dir [lindex $argv 1] ;# Location of fvwm2 modules.

set Exec1 [lindex $argv 2]      ;# Executable for the top button.
set Class1 [lindex $argv 3]     ;# Class/resource of the window opened
				 # when Exec1 starts.
set Label1 [lindex $argv 4]     ;# Label to display on the top button.

set Exec2 [lindex $argv 5]      ;# Executable for the bottom button.
set Class2 [lindex $argv 6]     ;# Class/resource of the window opened
				 # when Exec2 starts.
set Label2 [lindex $argv 7]     ;# Label to display on the bottom
				 # button.

# Reading optional command-line arguments.

for {set i 0} {$i < $argc} {incr i} {
    set arg [lindex $argv $i]

    switch -exact -- $arg {
        "-fg" {
            option add "*foreground" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-bg" {
            option add "*background" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-fn" {
            option add "*font" [lindex $argv [expr $i + 1]]
            incr i
        }
        default {
        }
    }
}

### PROCEDURES ###

# CommandEntry
# ------------
# Procedure for label+entry widgets.

proc CommandEntry { name label width args } {

    frame $name
    label $name.label -text $label -width $width -anchor w
    eval {entry $name.entry -relief sunken} $args
    pack $name.label -side left
    pack $name.entry -side right -fill x -expand true
}

# FileDialog
# ----------
# Procedure for launching a file browser.

proc FileDialog {w ent} {

    global base_dir

    #   Type names		Extension(s)	Mac File Type(s)
    #---------------------------------------------------------
    set types {
	{"Bitmap/Pixmap Files"  {.xbm .xpm}     }
	{"All Files"		*}
    }

    #	{"Image Files"		{.gif}		}
    #	{"Image Files"		{.jpeg .jpg}	}
    #	{"Image Files"		""		{GIFF JPEG}}
    #	{"Text Files"		{.txt .doc}	}
    #	{"Text Files"		{}		TEXT}
    #	{"Tcl Scripts"		{.tcl}		TEXT}
    #	{"C Source Files"	{.c .h}		}
    #	{"All Source Files"	{.tcl .c .h}	}

    set file [tk_getOpenFile -initialdir $base_dir/icons \
	    -filetypes $types -parent $w]

    if [string compare $file ""] {
	$ent delete 0 end
	$ent insert 0 $file
	$ent xview end
    }
}

# ClassHelp
# ---------
# Procedure for getting help on the Class/Resource entry field.

proc ClassHelp { button_name spec_button_name button_adj } {

    global base_dir

    exec $base_dir/bin/class_help_2.tcl $button_name $spec_button_name \
	    $button_adj
}

# ExecHelp
# --------
# Procedure for getting help on the Executable entry field.

proc ExecHelp { button_name spec_button_name button_adj \
	app_eg_desc app_eg_title app_eg_exec} {

    global base_dir

    exec $base_dir/bin/exec_help_3.tcl $button_name $spec_button_name \
	    $button_adj $app_eg_desc $app_eg_title $app_eg_exec
}

# LabelHelp
# ---------
# Procedure for getting help w/choosing a label for the button.

proc LabelHelp { button_name spec_button_name button_adj } {

    global base_dir

    exec $base_dir/bin/label_help.tcl $button_name $spec_button_name \
	    $button_adj
}

# ApplyResults
# ------------
# Procedure for writing new macro settings to ~/.fvwm2-ade/bbar.m4

proc ApplyResults {} {

    global base_dir
    global class1_macro
    global exec1_macro
    global label1_macro
    global Class1
    global Exec1
    global Label1
    global class2_macro
    global exec2_macro
    global label2_macro
    global Class2
    global Exec2
    global Label2

    # Change the macro definitions.

    exec $base_dir/bin/changemacro bbar.m4 $class1_macro "$Class1"
    exec $base_dir/bin/changemacro bbar.m4 $exec1_macro "$Exec1"
    exec $base_dir/bin/changemacro bbar.m4 $label1_macro "$Label1"
    exec $base_dir/bin/changemacro bbar.m4 $class2_macro "$Class2"
    exec $base_dir/bin/changemacro bbar.m4 $exec2_macro "$Exec2"
    exec $base_dir/bin/changemacro bbar.m4 $label2_macro "$Label2"
}

# Procedure to apply macro settings and to then exit gracefully.

proc ApplyAndQuit {} {

    global module_dir

    ApplyResults
    exec $module_dir/FvwmCommand "FvwmForm RestartVerify"
    exit 0
}

### VARIABLES ###

set class1_macro B1TOOLCLASS
set exec1_macro B1TOOLEXEC
set label1_macro B1TOOLLABEL

set class2_macro B2TOOLCLASS
set exec2_macro B2TOOLEXEC
set label2_macro B2TOOLLABEL

set button_name "Application"
set button1_name "Upper"
set button1_desc "upper"
set button2_name "Lower"
set button2_desc "lower"
set button_desc "application"
set app_eg_desc "the vi editor"
set app_eg_title vi
set app_eg_exec vi

### WIDGETS ###

wm title . "fvwm2-ade $button_name Configuration"

# Top frame; contains the title.
frame .top -relief raised -borderwidth 1
pack .top -side top -fill both -expand 1

# Extra frame to provide some padding.
frame .top.t -relief flat
pack .top.t -padx 10 -pady 10 -fill x

# Title label.
label .top.t.label -text "\"$button_name\" Buttons"
pack .top.t.label -padx 5

# Middle frame; contains all the configuration widgets.
frame .mid -relief raised -borderwidth 1
pack .mid -expand true -fill both -ipady 5

# Frame for setting the executable, class/resource, and name for the
# upper button.
frame .mid.butt1 -relief groove -borderwidth 2
pack .mid.butt1 -fill x -padx 10 -pady 10

# Extra frame to provide padding.
frame .mid.butt1.p -relief flat
pack .mid.butt1.p -pady 5

# Title for this section.
label .mid.butt1.p.label -text "$button1_name Button"
pack .mid.butt1.p.label -padx 5 -pady 5

# Frame to contain label, entry field, and "Help" button for the
# executable.
frame .mid.butt1.p.exec -relief flat
pack .mid.butt1.p.exec -fill x -padx 5 -side top

# label+entry widget for the executable.
CommandEntry .mid.butt1.p.exec.text "Executable:" 16 \
	-textvariable Exec1
pack .mid.butt1.p.exec.text -fill x -padx 5 -side left

# "Help" button for the executable.
button .mid.butt1.p.exec.help -text Help -cursor question_arrow \
	-command "ExecHelp \"$button_name\" \"$button1_name\"\
	\"$button1_desc\" \"$app_eg_desc\" \"$app_eg_title\"\
	\"$app_eg_exec\""
pack .mid.butt1.p.exec.help -fill x -padx 5 -side right 

# Frame to contain label, entry field, and help button for the
# class/resource.
frame .mid.butt1.p.class -relief flat
pack .mid.butt1.p.class -padx 5 -fill x

# label+entry widget for the class/resource.
CommandEntry .mid.butt1.p.class.text "Class/Resource:" 16 \
	-textvariable Class1
pack .mid.butt1.p.class.text -side left -padx 5 -fill x

# "Help" button for the class/resource.
button .mid.butt1.p.class.help -text Help -cursor question_arrow \
	-command "ClassHelp \"$button_name\" \"$button1_name\"\
	\"$button1_desc\""
pack .mid.butt1.p.class.help -side right -padx 5 -fill x

# Frame to contain label, entry field, and help button for the
# button label text.
frame .mid.butt1.p.lab1 -relief flat
pack .mid.butt1.p.lab1 -side bottom -padx 5 -fill x

# label+entry widget for the button label text.
CommandEntry .mid.butt1.p.lab1.text "Label:" 16 \
	-textvariable Label1
pack .mid.butt1.p.lab1.text -side left -padx 5 -fill x

# "Help" button for the button label text.
button .mid.butt1.p.lab1.help -text Help -cursor question_arrow \
	-command "LabelHelp \"$button_name\" \"$button1_name\" \
	\"$button1_desc\""
pack .mid.butt1.p.lab1.help -side right -padx 5 -fill x

# Frame for setting the executable, class/resource, and name for the
# lower button.
frame .mid.butt2 -relief groove -borderwidth 2
pack .mid.butt2 -fill x -padx 10

# Extra frame to provide padding.
frame .mid.butt2.p -relief flat
pack .mid.butt2.p -pady 5

# Title for this section.
label .mid.butt2.p.label -text "Lower Button"
pack .mid.butt2.p.label -padx 5 -pady 5

# Frame to contain label, entry field, and "Help" button for the
# executable.
frame .mid.butt2.p.exec -relief flat
pack .mid.butt2.p.exec -fill x -padx 5 -side top

# label+entry widget for the executable.
CommandEntry .mid.butt2.p.exec.text "Executable:" 16 \
	-textvariable Exec2
pack .mid.butt2.p.exec.text -fill x -padx 5 -side left

# "Help" button for the executable.
button .mid.butt2.p.exec.help -text Help -cursor question_arrow \
	-command "ExecHelp \"$button_name\" \"$button2_name\"\
	\"$button2_desc\" \"$app_eg_desc\" \"$app_eg_title\"\
	\"$app_eg_exec\""
pack .mid.butt2.p.exec.help -fill x -padx 5 -side right 

# Frame to contain label, entry field, and help button for the
# class/resource.
frame .mid.butt2.p.class -relief flat
pack .mid.butt2.p.class -padx 5 -fill x

# label+entry widget for the class/resource.
CommandEntry .mid.butt2.p.class.text "Class/Resource:" 16 \
	-textvariable Class2
pack .mid.butt2.p.class.text -side left -padx 5 -fill x

# "Help" button for the class/resource.
button .mid.butt2.p.class.help -text Help -cursor question_arrow \
	-command "ClassHelp \"$button_name\" \"$button2_name\"\
	\"$button2_desc\""
pack .mid.butt2.p.class.help -side right -padx 5 -fill x

# Frame to contail label, entry field, and help button for the
# button label text.
frame .mid.butt2.p.lab1 -relief flat
pack .mid.butt2.p.lab1 -side bottom -padx 5 -fill x

# label+entry widget for the button label text.
CommandEntry .mid.butt2.p.lab1.text "Label:" 16 \
	-textvariable Label2
pack .mid.butt2.p.lab1.text -side left -padx 5 -fill x

# "Help" button for the button label text.
button .mid.butt2.p.lab1.help -text Help -cursor question_arrow \
	-command "LabelHelp \"$button_name\" \"$button2_name\" \
	\"$button2_desc\""
pack .mid.butt2.p.lab1.help -side right -padx 5 -fill x

# Bottom frame; contains "OK" and "Cancel" buttons.
frame .bottom -relief raised -borderwidth 1
pack .bottom -side bottom -fill both -expand 1

# Extra frame to provide interior padding.
frame .bottom.f2 -relief flat -borderwidth 15
pack .bottom.f2 -side bottom

# "OK" button.
button .bottom.f2.ok -text OK -command ApplyAndQuit
pack .bottom.f2.ok -side left -padx 10

# "Cancel" button.
button .bottom.f2.cancel -text Cancel -command exit
pack .bottom.f2.cancel -side right -padx 10
