#!/usr/bin/wish -f

# Help dialog for choosing the class or resource of a button in the
# fvwm2-ade implementation of FvwmButtons.  This version has a few
# flourishes over class_help_1.tcl, to accomodate descriptions of the
# two application buttons.

# Greg Fall
# March 1998

# Reading required command-line arguments.

set button_name [lindex $argv 0]      ;# proper name of fvwm2-ade button
set spec_button_name [lindex $argv 1] ;# an adjective to put before
				       # button_name
set button_adj [lindex $argv 2]       ;# non-proper name of fvwm2-ade
				       # button

# Reading optional command-line arguments.

for {set i 0} {$i < $argc} {incr i} {
    set arg [lindex $argv $i]

    switch -exact -- $arg {
        "-fg" {
            option add "*foreground" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-bg" {
            option add "*background" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-fn" {
            option add "*font" [lindex $argv [expr $i + 1]]
            incr i
        }
        default {
        }
    }
}

# Main procedure.

proc HelpDialog {text1 text2 titl} {

    wm title . $titl

    # Top frame; contains an info bitmap and a terse message.
    frame .header -relief raised -borderwidth 1
    pack .header -side top -fill both -expand true

    # Extra frame to provide some padding.
    frame .header.f2 -relief flat -borderwidth 20
    pack .header.f2 -side top -fill both -expand true

    # Info bitmap.
    label .header.f2.i -bitmap info -bd 0
    pack .header.f2.i -side left

    # Empty frame to create space between the bitmap and the text.
    frame .header.f2.blank -bd 0 -width 15
    pack .header.f2.blank -side left

    # The upper window's message text.
    message .header.f2.msg -justify left -text $text1 -width 310 -bd 0
    pack .header.f2.msg -side right

    # Middle frame; contains a more elaborate description.
    frame .center -relief raised -borderwidth 1
    pack .center -side top -fill both -expand true

    # Extra frame to provide some padding.
    frame .center.f2 -relief flat -borderwidth 15
    pack .center.f2 -side top -fill both -expand true

    # The middle frame's message text.
    message .center.f2.msg1 -justify left -text $text2 -bd 0 -width 330
    pack .center.f2.msg1 -side top -fill both -expand true

    # Bottom frame; contains the "OK" button.
    frame .bottom -relief raised -borderwidth 1
    pack .bottom -side bottom -fill both -expand true

    # Extra frame to provide some padding.
    frame .bottom.f2 -relief flat -borderwidth 15
    pack .bottom.f2 -side bottom -fill both -expand true

    # "OK" button.
    button .bottom.f2.ok -text OK -command exit
    pack .bottom.f2.ok

}

### VARIABLES ###

set titl "fvwm2-ade $spec_button_name $button_name - Class/Resource"

set t1 "Enter the class or resource associated with the window in\
which the application started by the $button_adj of the two\
\"$button_name\" buttons runs."

set t2 "This portion is optional.  If included, then when the\
$button_adj \"$button_name\" button is pressed it will remain pressed\
(but not inoperative) until the window with the specified class or\
resource appears.  If you want to use this option and do not know the\
class or resource associated with the desired application's window, use\
the FvwmIdent module on the running application to get the information\
(FvwmIdent is accessible by default from the rightmost, or \"F\",\
button on the fvwm2-ade button bar, or from the \"Modules\" section of\
the \"F\" button's popup menu, or from the \"fvwm2 Modules\" section of\
the \"Program Menu\" accessible from the root window.  Launch the\
module, then click your mouse over the window of interest).

If this field is left blank, the button will still work; it just won't\
remain in the down position after getting pressed."

HelpDialog $t1 $t2 $titl
