#!/usr/bin/wish -f

# Dialog for setting up the fvwm2-ade button bar's "Desktop Tool"
# button.

# Greg Fall
# March 1998

# Reading required command-line arguments.

set base_dir [lindex $argv 0]   ;# fvwm2-ade installation directory
set module_dir [lindex $argv 1] ;# Location of fvwm2 modules.

set Exec [lindex $argv 2]  ;# Executable to run with this button.
set Class [lindex $argv 3] ;# Class/resource of the window opened when
			    # Exec starts.
set Icon [lindex $argv 4]  ;# Icon to display on this button.

# Reading optional command-line areguments.

for {set i 0} {$i < $argc} {incr i} {
    set arg [lindex $argv $i]

    switch -exact -- $arg {
        "-fg" {
            option add "*foreground" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-bg" {
            option add "*background" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-fn" {
            option add "*font" [lindex $argv [expr $i + 1]]
            incr i
        }
        default {
        }
    }
}

### PROCEDURES ###

# CommandEntry
# ------------
# Procedure for label+entry widgets.

proc CommandEntry { name label width args } {

    frame $name
    label $name.label -text $label -width $width -anchor w
    eval {entry $name.entry -relief sunken} $args
    pack $name.label -side left
    pack $name.entry -side right -fill x -expand true
}

# FileDialog
# ----------
# Procedure for launching a file browser.

proc FileDialog {w ent} {

    global base_dir

    #   Type names		Extension(s)	Mac File Type(s)
    #---------------------------------------------------------
    set types {
	{"Bitmap/Pixmap Files"  {.xbm .xpm}     }
	{"All Files"		*}
    }

    #	{"Image Files"		{.gif}		}
    #	{"Image Files"		{.jpeg .jpg}	}
    #	{"Image Files"		""		{GIFF JPEG}}
    #	{"Text Files"		{.txt .doc}	}
    #	{"Text Files"		{}		TEXT}
    #	{"Tcl Scripts"		{.tcl}		TEXT}
    #	{"C Source Files"	{.c .h}		}
    #	{"All Source Files"	{.tcl .c .h}	}

    set file [tk_getOpenFile -initialdir $base_dir/icons \
	    -filetypes $types -parent $w]

    if [string compare $file ""] {
	$ent delete 0 end
	$ent insert 0 $file
	$ent xview end
    }
}

# ClassHelp
# ---------
# Procedure for getting help on the Class/Resource entry field.

proc ClassHelp { button_name button_desc } {

    global base_dir

    exec $base_dir/bin/class_help_1.tcl $button_name $button_desc
}

# ExecHelp
# --------
# Procedure for getting help on the Executable entry field.

proc ExecHelp { button_name button_desc app_eg_desc app_eg_title \
	app_eg_exec} {

    global base_dir

    exec $base_dir/bin/exec_help_1.tcl $button_name $button_desc \
	    $app_eg_desc $app_eg_title $app_eg_exec
}

# IconHelp
# --------
# Procedure for getting help w/choosing an icon for the button.

proc IconHelp { button_name icon_eg_dir icon_eg_file } {

    global base_dir

    exec $base_dir/bin/icon_help.tcl $base_dir $button_name \
	    $icon_eg_dir $icon_eg_file
}

# ApplyResults
# ------------
# Procedure for writing new macro settings to ~/.fvwm2-ade/bbar.m4

proc ApplyResults {} {

    global base_dir
    global class_macro
    global exec_macro
    global icon_macro
    global Class
    global Exec
    global Icon

    # Change the macro definitions.

    exec $base_dir/bin/changemacro bbar.m4 $class_macro $Class
    exec $base_dir/bin/changemacro bbar.m4 $exec_macro "$Exec"
    exec $base_dir/bin/changemacro bbar.m4 $icon_macro $Icon
}

# ApplyAndQuit
# ------------
# Procedure to apply macro settings and to then exit gracefully.

proc ApplyAndQuit {} {

    global module_dir

    ApplyResults
    exec $module_dir/FvwmCommand "FvwmForm RestartVerify"
    exit 0
}

### VARIABLES ###

set class_macro DESKTOOLCLASS ;# M4 macros defined in
set exec_macro DESKTOOLEXEC   ;# ~/.fvwm2-ade/bbar.m4 and
set icon_macro DESKTOOLICON   ;# changed by this GUI.

set button_name "Desktop Tool" ;# Used when referring specifically to
				# the button.

set button_desc "desktop tool" ;# Used when referring to the class of
			        # application the button represents.

# app_eg_desc is used like this:  "If you want the $button_name button
# to start $app_eg_desc, you should..."
set app_eg_desc "the character terminal version of the X-Window"
set app_eg_desc "$app_eg_desc Programming Environment"

set app_eg_title "X-Window Prog. Env." ;# Title for the xterm in which
					# the example app runs.

set app_eg_exec wpe ;# Example executable.

set icon_eg_dir dtapps ;# Directory below $base_dir in which icons for
		        # this button can be found.

set icon_eg_file hammer_doc.xpm ;# Specific (usually default) pixmap
				 # for this button, found in
			         # $base_dir/$icon_eg_dir.

### WIDGETS ###

wm title . "fvwm2-ade $button_name Configuration"

# Top frame; contains the title.
frame .top -relief raised -borderwidth 1
pack .top -side top -fill both -expand 1

# Extra frame to provide some padding.
frame .top.t -relief flat
pack .top.t -padx 10 -pady 10 -fill x

# Title label.
label .top.t.label -text "\"$button_name\" Button"
pack .top.t.label -padx 5

# Desktop tool image.
image create photo "desk_tool_image" -file $base_dir/bin/art/hammer_doc.gif
label .top.t.image -image desk_tool_image
pack .top.t.image -pady 5

# Middle frame; contains all the configuration widgets.
frame .mid -relief raised -borderwidth 1
pack .mid -expand true -fill both -ipady 5

# Frame for setting the executable and class/resource.
frame .mid.prog -relief groove -borderwidth 2
pack .mid.prog -fill x -padx 10 -pady 10

# Extra frame to provide padding.
frame .mid.prog.p -relief flat
pack .mid.prog.p -pady 5

# Frame to contain label, entry field, and "Help" button for the
# executable.
frame .mid.prog.p.exec -relief flat
pack .mid.prog.p.exec -fill x -padx 5 -side top

# label+entry widget for the executable.
CommandEntry .mid.prog.p.exec.text "Executable:" 16 \
	-textvariable Exec
pack .mid.prog.p.exec.text -fill x -padx 5 -side left

# "Help" button for the executable.
button .mid.prog.p.exec.help -text Help -cursor question_arrow \
	-command "ExecHelp \"$button_name\" \"$button_desc\" \
	\"$app_eg_desc\" \"$app_eg_title\" \"$app_eg_exec\""
pack .mid.prog.p.exec.help -fill x -padx 5 -side right 

# Frame to contail label, entry field, and help button for the
# class/resource.
frame .mid.prog.p.class -relief flat
pack .mid.prog.p.class -side bottom -padx 5 -fill x

# label+entry widget for the class/resource.
CommandEntry .mid.prog.p.class.text "Class/Resource:" 16 \
	-textvariable Class
pack .mid.prog.p.class.text -side left -padx 5 -fill x

# "Help" button for the class/resource.
button .mid.prog.p.class.help -text Help -cursor question_arrow \
	-command "ClassHelp \"$button_name\" \"$button_desc\""
pack .mid.prog.p.class.help -side right -padx 5 -fill x

# Frame for choosing the button icon.
frame .mid.icon -relief groove -borderwidth 2
pack .mid.icon -padx 10 -fill x -ipady 4

# Extra frame to provide interior padding.
frame .mid.icon.i
pack .mid.icon.i -padx 10 -fill x

# label+entry field for the icon file.
CommandEntry .mid.icon.i.text Icon: 5 -textvariable Icon
pack .mid.icon.i.text -fill x -pady 8 -side top

# Frame to contain "Browse" and "Help" buttons associated with choosing
# the icon file.
frame .mid.icon.i.buttons
pack .mid.icon.i.buttons -side bottom

# "Browse" button for starting a file browser.
button .mid.icon.i.buttons.browse -text Browse \
	-command "FileDialog . .mid.icon.i.text.entry"
pack .mid.icon.i.buttons.browse -side left -padx 5

# "Help" button for the icon.
button .mid.icon.i.buttons.help -text Help -cursor question_arrow \
	-command "IconHelp \"$button_name\" \"$icon_eg_dir\" \
	\"$icon_eg_file\""
pack .mid.icon.i.buttons.help -side right -padx 5

# Bottom frame; contains "OK" and "Cancel" buttons.
frame .bottom -relief raised -borderwidth 1
pack .bottom -side bottom -fill both -expand 1

# Extra frame to provide interior padding.
frame .bottom.f2 -relief flat -borderwidth 15
pack .bottom.f2 -side bottom

# "OK" button.
button .bottom.f2.ok -text OK -command ApplyAndQuit
pack .bottom.f2.ok -side left -padx 10

# "Cancel" button.
button .bottom.f2.cancel -text Cancel -command exit
pack .bottom.f2.cancel -side right -padx 10
