#!/usr/bin/wish -f

# Help dialog for choosing the application associated with an
# application button in the fvwm2-ade implementation of FvwmButtons.

# Greg Fall
# March 1998

# Reading required command-line arguments.

set button_name [lindex $argv 0]
set spec_button_name [lindex $argv 1]
set button_adj [lindex $argv 2]
set app_eg_desc [lindex $argv 3]
set app_eg_title [lindex $argv 4]
set app_eg_exec [lindex $argv 5]

# Reading optional command-line arguments.

for {set i 0} {$i < $argc} {incr i} {
    set arg [lindex $argv $i]

    switch -exact -- $arg {
        "-fg" {
            option add "*foreground" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-bg" {
            option add "*background" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-fn" {
            option add "*font" [lindex $argv [expr $i + 1]]
            incr i
        }
        default {
        }
    }
}

# Main procedure.

proc HelpDialog {text1 text2 text3 text4 titl} {

    wm title . $titl

    # Top frame; contains an info bitmap and a terse message.
    frame .header -relief raised -borderwidth 1
    pack .header -side top -fill both -expand 1

    # Extra frame to provide padding.
    frame .header.f2 -relief flat -borderwidth 20
    pack .header.f2 -side top -fill both -expand 1

    # Info bitmap.
    label .header.f2.i -bitmap info -bd 0
    pack .header.f2.i -side left

    # Empty frame to create space between the bitmap and the text.
    frame .header.f2.blank -bd 0 -width 15
    pack .header.f2.blank -side left

    # The upper frame's message text.
    message .header.f2.msg -justify left -text $text1 -width 310 -bd 0
    pack .header.f2.msg -side right

    # Middle frame; contains a more elaborate description.
    frame .center -relief raised -borderwidth 1
    pack .center -side top -fill both -expand 1

    # Extra frame to provide padding.
    frame .center.f2 -relief flat -borderwidth 15
    pack .center.f2 -side top -fill both -expand 1

    # First paragraph of the middle frame's text.
    message .center.f2.msg1 -justify left -text $text2 -width 330 -bd 0
    pack .center.f2.msg1 -side top -fill both -expand 1

    # The centered item following the first paragraph.
    message .center.f2.msg2 -justify center -text $text3 -width 330 -bd 10
    pack .center.f2.msg2 -side top -fill both -expand 1

    # Second paragraph of the middle frame's text.
    message .center.f2.msg3 -justify left -text $text4 -width 330 -bd 0
    pack .center.f2.msg3 -side top -fill both -expand 1

    # Bottom frame; contains the "OK" button.
    frame .bottom -relief raised -borderwidth 1
    pack .bottom -side bottom -fill both -expand 1

    # Extra frame to provide padding.
    frame .bottom.f2 -relief flat -borderwidth 15
    pack .bottom.f2 -side bottom -fill both -expand 1

    # "OK" button.
    button .bottom.f2.ok -text OK -command exit
    pack .bottom.f2.ok

}

set titl "fvwm2-ade $spec_button_name $button_name - Executable"

set t1 \
"Enter the executable to run when the $button_adj of the two\
\"$button_name\" buttons is pressed."

set t2 \
"You will not usually need to include the full path to the executable\
here.  However, the default path searched for executables by fvwm2\
depends on the way your X sessions are started, and it may or may not\
be the same as the path used in your shell.  Because of this\
ambiguity, fvwm2 may not use the same path you are used to, and in\
some cases will not find executables without being given their full\
paths.

If your preferred application does not run in its own window, you\
will need to run it in an X terminal window.  For example, if you want\
the $button_adj \"$button_name\" button to start $app_eg_desc, you\
should enter the following, or something similar:"

set t3 "xterm -T \"$app_eg_title\" -e $app_eg_exec"

set t4 \
"(The above command will start an xterm with the title \"$app_eg_title\"\
and will execute $app_eg_exec inside the xterm.  See the xterm man page\
for more information.)"

HelpDialog $t1 $t2 $t3 $t4 $titl
