#!/usr/bin/wish -f

# Help dialog for choosing the icon displayed on a specific button in
# the fvwm2-ade implementation of FvwmButtons

# Greg Fall
# October 1997

# Reading required command-line arguments.

set user_dir $env(HOME)/.fvwm2-ade
set base_dir [lindex $argv 0]
set button_name [lindex $argv 1]
set icon_eg_dir [lindex $argv 2]
set icon_eg_file [lindex $argv 3]

# Reading optional command-line arguments.

for {set i 0} {$i < $argc} {incr i} {
    set arg [lindex $argv $i]

    switch -exact -- $arg {
        "-fg" {
            option add "*foreground" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-bg" {
            option add "*background" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-fn" {
            option add "*font" [lindex $argv [expr $i + 1]]
            incr i
        }
        default {
        }
    }
}

# Main procedure.

proc HelpDialog {text1 text2 text3 titl} {

    wm title . $titl

    # Top frame; contains an info bitmap and a terse message.
    frame .header -relief raised -borderwidth 1
    pack .header -side top -fill both -expand 1

    # Extra frame to provide padding.
    frame .header.f2 -relief flat -borderwidth 20
    pack .header.f2 -side top -fill both -expand 1

    # Info bitmap.
    label .header.f2.i -bitmap info -bd 0
    pack .header.f2.i -side left

    # Empty frame to create space between the bitmap and the text.
    frame .header.f2.blank -bd 0 -width 15
    pack .header.f2.blank -side left

    # The upper frame's message text.
    message .header.f2.msg -justify left -text $text1 -width 310 -bd 0
    pack .header.f2.msg -side right

    # Middle frame; contains a more elaborate description.
    frame .center -relief raised -borderwidth 1
    pack .center -side top -fill both -expand 1

    # Extra frame to provide padding.
    frame .center.f2 -relief flat -borderwidth 15
    pack .center.f2 -side top -fill both -expand 1

    # First paragraph of the middle frame's text.
    message .center.f2.msg1 -justify left -text $text2 -width 330 -bd 0
    pack .center.f2.msg1 -side top -fill both -expand 1

    # The centered item following the first paragraph.
    message .center.f2.msg2 -justify center -text $text3 -width 330 \
	    -bd 10
    pack .center.f2.msg2 -side bottom -fill both -expand 1

    # Bottom frame; contains the "OK" button.
    frame .bottom -relief raised -borderwidth 1
    pack .bottom -side bottom -fill both -expand 1

    # Extra frame to provide padding.
    frame .bottom.f2 -relief flat -borderwidth 15
    pack .bottom.f2 -side bottom -fill both -expand 1

    # "OK" button.
    button .bottom.f2.ok -text OK -command exit
    pack .bottom.f2.ok

}

set titl "fvwm2-ade $button_name - Icon"

set t1 \
"Enter the icon you want displayed on the button bar's\
\"$button_name\" button."

set t2 "The FvwmButtons module uses xpm icons.  If the directory\
containing the icon you wish to use is included in either of the fvwm2\
settings \"IconPath\" or \"PixmapPath\", then you do not need to\
provide the full pathname of the icon file.  However, if neither\
\"IconPath\" nor \"PixmapPath\" includes the directory in which the\
icon resides, then you must give the icon file's full pathname here.\
Examine the file $user_dir/paths to determine these paths (if you want,\
go ahead and add other directories to the paths by editing\
$user_dir/paths).

Look in $base_dir/icons/$icon_eg_dir for some icons you may want to\
use.  Since the $base_dir/icons directory is by default a part of your\
\"PixmapPath\", then you can include any of the files in the\
subdirectories below it by indicating, for example,"

set t3 "$icon_eg_dir/$icon_eg_file"

HelpDialog $t1 $t2 $t3 $titl
