#!/usr/bin/wish -f

# Help dialog for choosing the icon displayed on a specific button in
# the fvwm2-ade implementation of FvwmButtons

# Greg Fall
# October 1997

set user_dir $env(HOME)/.fvwm2-ade

# Reading required command-line arguments.

set button_name [lindex $argv 0]
set spec_button_name [lindex $argv 1]
set button_adj [lindex $argv 2]

# Reading optional command-line arguments.

for {set i 0} {$i < $argc} {incr i} {
    set arg [lindex $argv $i]

    switch -exact -- $arg {
        "-fg" {
            option add "*foreground" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-bg" {
            option add "*background" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-fn" {
            option add "*font" [lindex $argv [expr $i + 1]]
            incr i
        }
        default {
        }
    }
}

# Main procedure.

proc HelpDialog {text1 text2 titl} {

    wm title . $titl

    # Top frame; contains an info bitmap and a terse message.
    frame .header -relief raised -borderwidth 1
    pack .header -side top -fill both -expand 1

    # Extra frame to provide padding.
    frame .header.f2 -relief flat -borderwidth 20
    pack .header.f2 -side top -fill both -expand 1

    # Info bitmap.
    label .header.f2.i -bitmap info -bd 0
    pack .header.f2.i -side left

    # Empty frame to create space between the bitmap and the text.
    frame .header.f2.blank -bd 0 -width 15
    pack .header.f2.blank -side left

    # The upper frame's message text.
    message .header.f2.msg -justify left -text $text1 -width 310 -bd 0
    pack .header.f2.msg -side right

    # Middle frame; contains a more elaborate description.
    frame .center -relief raised -borderwidth 1
    pack .center -side top -fill both -expand 1

    # Extra frame to provide padding.
    frame .center.f2 -relief flat -borderwidth 15
    pack .center.f2 -side top -fill both -expand 1

    # The middle frame's text.
    message .center.f2.msg1 -justify left -text $text2 -width 330 -bd 0
    pack .center.f2.msg1 -side top -fill both -expand 1

    # Bottom frame; contains the "OK" button.
    frame .bottom -relief raised -borderwidth 1
    pack .bottom -side bottom -fill both -expand 1

    # Extra frame to provide padding.
    frame .bottom.f2 -relief flat -borderwidth 15
    pack .bottom.f2 -side bottom -fill both -expand 1

    # "OK" button.
    button .bottom.f2.ok -text OK -command exit
    pack .bottom.f2.ok

}

set titl "fvwm2-ade $spec_button_name $button_name - Label"

set t1 \
"Enter the label you want displayed on the $button_adj of the two\
\"$button_name\"\ buttons."

set t2 \
"If this label is too long, the FvwmButtons module will truncate it to\
fit the button, and it will look funny.  If you desperately want to use\
a label that doesn't currently fit, change the setting of the\
BUTTONBARFONT macro in $user_dir/fonts.m4 to something smaller (the\
xfontsel utility found in most Linux distributions is helpful for\
finding fonts)."

HelpDialog $t1 $t2 $titl
