#!/usr/bin/wish -f

# Dialog for setting up the FvwmPager module that gets swallowed by the
# fvwm2-ade button bar.

# Greg Fall
# March 1998

# Reading required command-line arguments.

set userdir $env(HOME)/.fvwm2-ade
set basedir [lindex $argv 0]
set moduledir [lindex $argv 1]
set wid [lindex $argv 2]
set hgt [lindex $argv 3]
set dtops [lindex $argv 4]
set labflag [lindex $argv 5]
set lab0 [lindex $argv 6]
set lab1 [lindex $argv 7]
set lab2 [lindex $argv 8]
set lab3 [lindex $argv 9]
set lab4 [lindex $argv 10]

# Reading optional command-line arguments.

for {set i 0} {$i < $argc} {incr i} {
    set arg [lindex $argv $i]

    switch -exact -- $arg {
        "-fg" {
            option add "*foreground" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-bg" {
            option add "*background" [lindex $argv [expr $i + 1]]
            incr i
        }
        "-fn" {
            option add "*font" [lindex $argv [expr $i + 1]]
            incr i
        }
        default {
        }
    }
}

### PROCEDURES ###

# OnOffEntry
# ----------
# Procedure for disabling label+entry widgets after scale changes.

proc OnOffEntry { } {

    global fgc
    global bgc
    global labflag
    global dtops

    if { [string compare $labflag off] == 0} {

	    .mid.labels.label0.entry configure -state disabled -fg $bgc
	    .mid.labels.label1.entry configure -state disabled -fg $bgc
	    .mid.labels.label2.entry configure -state disabled -fg $bgc
	    .mid.labels.label3.entry configure -state disabled -fg $bgc
	    .mid.labels.label4.entry configure -state disabled -fg $bgc

    } else {

	switch -exact -- $dtops {
	    "1" {
		.mid.labels.label0.entry configure -state normal -fg $fgc
		.mid.labels.label1.entry configure -state disabled -fg $bgc
		.mid.labels.label2.entry configure -state disabled -fg $bgc
		.mid.labels.label3.entry configure -state disabled -fg $bgc
		.mid.labels.label4.entry configure -state disabled -fg $bgc
	    }
	    "2" {
		.mid.labels.label0.entry configure -state normal -fg $fgc
		.mid.labels.label1.entry configure -state normal -fg $fgc
		.mid.labels.label2.entry configure -state disabled -fg $bgc
		.mid.labels.label3.entry configure -state disabled -fg $bgc
		.mid.labels.label4.entry configure -state disabled -fg $bgc
	    }
	    "3" {
		.mid.labels.label0.entry configure -state normal -fg $fgc
		.mid.labels.label1.entry configure -state normal -fg $fgc
		.mid.labels.label2.entry configure -state normal -fg $fgc
		.mid.labels.label3.entry configure -state disabled -fg $bgc
		.mid.labels.label4.entry configure -state disabled -fg $bgc
	    }
	    "4" {
		.mid.labels.label0.entry configure -state normal -fg $fgc
		.mid.labels.label1.entry configure -state normal -fg $fgc
		.mid.labels.label2.entry configure -state normal -fg $fgc
		.mid.labels.label3.entry configure -state normal -fg $fgc
		.mid.labels.label4.entry configure -state disabled -fg $bgc
	    }
	    "5" {
		.mid.labels.label0.entry configure -state normal -fg $fgc
		.mid.labels.label1.entry configure -state normal -fg $fgc
		.mid.labels.label2.entry configure -state normal -fg $fgc
		.mid.labels.label3.entry configure -state normal -fg $fgc
		.mid.labels.label4.entry configure -state normal -fg $fgc
	    }
	    default {
		puts stderr "Unknown argument: $dtops"
	    }
	}
    }
}

# dummy
# -----
# Procedure for executing OnOffEntry.

proc dummy { dtops } {

    OnOffEntry

}

# CommandEntry
# ------------
# Procedure for label+entry widgets.

proc CommandEntry { name label width args } {
    frame $name
    label $name.label -text $label -width $width -anchor w
    eval {entry $name.entry -relief sunken} $args
    pack $name.label -side left
    pack $name.entry -side right -fill x -expand true
}

# ApplyResults
# ------------
# Procedure for writing new macro setting to ~/.fvwm2-ade/bbar.m4

proc ApplyResults { } {
   
    global userdir
    global basedir
    global wid
    global hgt
    global dtops
    global lab0
    global lab1
    global lab2
    global lab3
    global lab4
    global labflag

#   Change the macro definitions PAGERWIDTH, PAGERHEIGHT, NUMOFDESKTOPS,
#   PAGERLAB0, PAGERLAB1, PAGERLAB2, PAGERLAB3, and PAGERLAB4 in the
#   file ~/.fvwm2-ade/bbar.m4.

    exec $basedir/bin/changemacro bbar.m4 PAGERWIDTH $wid
    exec $basedir/bin/changemacro bbar.m4 PAGERHEIGHT $hgt
    exec $basedir/bin/changemacro bbar.m4 NUMOFDESKTOPS $dtops
    exec $basedir/bin/changemacro bbar.m4 PAGERLABFLAG $labflag
    exec $basedir/bin/changemacro bbar.m4 PAGERLAB0 $lab0
    exec $basedir/bin/changemacro bbar.m4 PAGERLAB1 $lab1
    exec $basedir/bin/changemacro bbar.m4 PAGERLAB2 $lab2
    exec $basedir/bin/changemacro bbar.m4 PAGERLAB3 $lab3
    exec $basedir/bin/changemacro bbar.m4 PAGERLAB4 $lab4
}

# ApplyAndQuit
# ------------
# Procedure to apply macro settings and to then exit gracefully.

proc ApplyAndQuit { } {

    global moduledir

    ApplyResults
    exec $moduledir/FvwmCommand "FvwmForm RestartVerify"
    exit 0
}

### WIDGETS ###

wm title . "Pager Configuration"

# Top frame; contains the title.
frame .top -relief raised -borderwidth 1
pack .top -side top -fill both -expand 1

# Extra frame to provide padding.
frame .top.t -relief flat
pack .top.t -padx 10 -pady 10 -fill x

# The title label.
label .top.t.label -text "FvwmPager Set-Up"
pack .top.t.label -padx 5

# An image of a pager to go with the title.
image create photo "pager_image" -file $basedir/bin/art/pager.gif
label .top.t.image -image pager_image
pack .top.t.image -pady 5 -fill x

# Middle frame; contains all the configuration widgets.
frame .mid -relief raised -borderwidth 1
pack .mid -fill both -expand 1

# Frame for setting the desktop size.
frame .mid.size -relief groove -borderwidth 2
pack .mid.size -padx 10 -pady 10 -fill x

# "Desktop Size" label.
label .mid.size.label -text "Desktop Size:"
pack .mid.size.label -side left -padx 5

# Frame to contain sliders.
frame .mid.size.sliders
pack .mid.size.sliders -side right -padx 5

# Slider for the desktop width.
scale .mid.size.sliders.width -from 1 -to 4 -length 60 -width 10 \
	    -variable wid -orient horizontal -label width
pack .mid.size.sliders.width -side left

# Slider for the desktop height.
scale .mid.size.sliders.height -from 1 -to 4 -length 60 -width 10 \
	    -variable hgt -orient horizontal -label height
pack .mid.size.sliders.height -side right

# Frame for setting the number of desktops.
frame .mid.desktops -relief groove -borderwidth 2
pack .mid.desktops -padx 10 -fill x

# "Number of Desktops" label.
label .mid.desktops.label -text "Number of Desktops:"
pack .mid.desktops.label -side left -padx 5

# Slider for setting the number of desktops.  You're mental if you need
# more than five desktops.
scale .mid.desktops.slider -from 1 -to 5 -length 75 -width 10 \
	  -variable dtops -orient horizontal -label "" \
	  -command dummy
pack .mid.desktops.slider -side right -padx 5

# Frame for desktop labels
frame .mid.labels -relief groove -borderwidth 2
pack .mid.labels -padx 10 -pady 10 -fill x -ipady 5

# Extra frame to provide padding.
frame .mid.labels.select
pack .mid.labels.select -padx 10 -pady 10

# "Desktop Labels" label.
label .mid.labels.select.label -text "Desktop Labels"
pack .mid.labels.select.label -side left -padx 5

# Frame to contain yes/no buttons for including titles on the desktops.
frame .mid.labels.select.buttons
pack .mid.labels.select.buttons -side right -padx 5

# Radio button for enabling desktop titles.
radiobutton .mid.labels.select.buttons.yes -variable labflag \
	-text yes -value on -command OnOffEntry
pack .mid.labels.select.buttons.yes -side left

# Radio button for disabling desktop titles.
radiobutton .mid.labels.select.buttons.no -variable labflag \
	-text no -value off -command OnOffEntry
pack .mid.labels.select.buttons.no -side right

set bgc [. cget -background]
set fgc [.top.t.label cget -foreground]

# Label+entry widgets for desktop titles.
CommandEntry .mid.labels.label0 "Desktop 0" 10 -textvariable lab0
CommandEntry .mid.labels.label1 "Desktop 1" 10 -textvariable lab1
CommandEntry .mid.labels.label2 "Desktop 2" 10 -textvariable lab2
CommandEntry .mid.labels.label3 "Desktop 3" 10 -textvariable lab3
CommandEntry .mid.labels.label4 "Desktop 4" 10 -textvariable lab4
pack .mid.labels.label0 .mid.labels.label1 .mid.labels.label2 \
	    .mid.labels.label3 .mid.labels.label4

# Bottom frame; contains "OK" and "Cancel" buttons.
frame .bottom -relief raised -borderwidth 1
pack .bottom -side bottom -fill both -expand 1

# Extra frame to provide padding.
frame .bottom.f2 -relief flat -borderwidth 15
pack .bottom.f2 -side bottom

# "OK" button.
button .bottom.f2.ok -text OK -command ApplyAndQuit
pack .bottom.f2.ok -side left -padx 10

# "Cancel" button
button .bottom.f2.cancel -text Cancel -command exit
pack .bottom.f2.cancel -side right -padx 10
